<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'Geen',
    'Edit' => 'Bewerken',
    'Remove' => 'Verwijderen',
    'Yes' => 'Ja',
    'No' => 'Nee',
    'cancel' => 'annuleren',
    'or' => 'of',
    'Yellow' => 'Geel',
    'Blue' => 'Blauw',
    'Green' => 'Groen',
    'Purple' => 'Paars',
    'Red' => 'Rood',
    'Orange' => 'Oranje',
    'Grey' => 'Grijs',
    'Brown' => 'Bruin',
    'Deep Orange' => 'Dieporanje',
    'Dark Grey' => 'Donkergrijs',
    'Pink' => 'Roze',
    'Teal' => 'Groenblauw',
    'Cyan' => 'Cyaan',
    'Lime' => 'Limoen',
    'Light Green' => 'Lichtgroen',
    'Amber' => 'Amber',
    'Save' => 'Opslaan',
    'Login' => 'Inloggen',
    'Official website:' => 'Officiële website:',
    'Unassigned' => 'Niet toegewezen',
    'View this task' => 'Deze taak bekijken',
    'Remove user' => 'Gebruiker verwijderen',
    'Do you really want to remove this user: "%s"?' => 'Wil je deze gebruiker echt verwijderen: "%s" ?',
    'All users' => 'Alle gebruikers',
    'Username' => 'Gebruikersnaam',
    'Password' => 'Wachtwoord',
    'Administrator' => 'Administrator',
    'Sign in' => 'Inloggen',
    'Users' => 'Gebruikers',
    'Forbidden' => 'Geweigerd',
    'Access Forbidden' => 'Toegang geweigerd',
    'Edit user' => 'Gebruiker bewerken',
    'Logout' => 'Uitloggen',
    'Bad username or password' => 'Verkeerde gebruikersnaam of wachtwoord',
    'Edit project' => 'Project bewerken',
    'Name' => 'Naam',
    'Projects' => 'Projecten',
    'No project' => 'Geen project',
    'Project' => 'Project',
    'Status' => 'Status',
    'Tasks' => 'Taken',
    'Board' => 'Bord',
    'Actions' => 'Acties',
    'Inactive' => 'Inactief',
    'Active' => 'Actief',
    'Unable to update this board.' => 'Kan dit bord niet bijwerken.',
    'Disable' => 'Deactiveren',
    'Enable' => 'Activeren',
    'New project' => 'Nieuw project',
    'Do you really want to remove this project: "%s"?' => 'Wil je dit project echt verwijderen: "%s"?',
    'Remove project' => 'Project verwijderen',
    'Edit the board for "%s"' => 'Bord bewerken voor "%s"',
    'Add a new column' => 'Kolom toevoegen',
    'Title' => 'Titel',
    'Assigned to %s' => 'Toegewezen aan %s',
    'Remove a column' => 'Kolom verwijderen',
    'Unable to remove this column.' => 'Kan deze kolom niet verwijderen.',
    'Do you really want to remove this column: "%s"?' => 'Wil je deze kolom echt verwijderen: "%s"?',
    'Settings' => 'Instellingen',
    'Application settings' => 'Applicatie-instellingen',
    'Language' => 'Taal',
    'Webhook token:' => 'Webhook token:',
    'API token:' => 'API token:',
    'Database size:' => 'Database-grootte:',
    'Download the database' => 'Database downloaden',
    'Optimize the database' => 'Database optimaliseren',
    '(VACUUM command)' => '(VACUUM commando)',
    '(Gzip compressed Sqlite file)' => '(Gzip ingepakt Sqlite-bestand)',
    'Close a task' => 'Taak sluiten',
    'Column' => 'Kolom',
    'Color' => 'Kleur',
    'Assignee' => 'Toegewezene',
    'Create another task' => 'Nog een taak aanmaken',
    'New task' => 'Nieuwe taak',
    'Open a task' => 'Een taak openen',
    'Do you really want to open this task: "%s"?' => 'Wil je deze taak echt openen: "%s"?',
    'Back to the board' => 'Terug naar het bord',
    'There is nobody assigned' => 'Er is niemand toegewezen',
    'Column on the board:' => 'Kolom op het bord:',
    'Close this task' => 'Deze taak sluiten',
    'Open this task' => 'Deze taak openen',
    'There is no description.' => 'Er is geen omschrijving.',
    'Add a new task' => 'Een nieuwe taak toevoegen',
    'The username is required' => 'De gebruikersnaam is verplicht',
    'The maximum length is %d characters' => 'De maximale lengte is %d tekens',
    'The minimum length is %d characters' => 'De minimale lengte is %d tekens',
    'The password is required' => 'Het wachtwoord is verplicht',
    'This value must be an integer' => 'Deze waarde dient een integer te zijn',
    'The username must be unique' => 'De gebruikersnaam moet uniek zijn',
    'The user id is required' => 'De gebruikers-ID is verplicht',
    'Passwords don\'t match' => 'De wachtwoorden komen niet overeen',
    'The confirmation is required' => 'De bevestiging is verplicht',
    'The project is required' => 'Het project is verplicht',
    'The id is required' => 'De ID is verplicht',
    'The project id is required' => 'De project-ID is verplicht',
    'The project name is required' => 'De projectnaam is verplicht',
    'The title is required' => 'De titel is verplicht',
    'Settings saved successfully.' => 'Instellingen succesvol opgeslagen.',
    'Unable to save your settings.' => 'Kan je instellingen niet opslaan.',
    'Database optimization done.' => 'Database optimaliseren voltooid.',
    'Your project has been created successfully.' => 'Je project is succesvol aangemaakt.',
    'Unable to create your project.' => 'Kan je project niet aanmaken.',
    'Project updated successfully.' => 'Project succesvol bijgewerkt.',
    'Unable to update this project.' => 'Kan dit project niet bijwerken.',
    'Unable to remove this project.' => 'Kan dit project niet verwijderen.',
    'Project removed successfully.' => 'Project succesvol verwijderd.',
    'Project activated successfully.' => 'Project succesvol geactiveerd.',
    'Unable to activate this project.' => 'Kan dit project niet activeren.',
    'Project disabled successfully.' => 'Project uitschakelen succesvol.',
    'Unable to disable this project.' => 'Kan dit project niet uitschakelen.',
    'Unable to open this task.' => 'Kan deze taak niet openen.',
    'Task opened successfully.' => 'Taak succesvol geopend.',
    'Unable to close this task.' => 'Kan deze taak niet sluiten.',
    'Task closed successfully.' => 'Taak succesvol gesloten.',
    'Unable to update your task.' => 'Kan je taak niet bijwerken.',
    'Task updated successfully.' => 'Taak succesvol bijgewerkt.',
    'Unable to create your task.' => 'Kan je taak niet aanmaken.',
    'Task created successfully.' => 'Taak succesvol aangemaakt.',
    'User created successfully.' => 'Gebruiker succesvol aangemaakt.',
    'Unable to create your user.' => 'Kan je gebruiker niet aanmaken.',
    'User updated successfully.' => 'Gebruiker succesvol bijgewerkt',
    'User removed successfully.' => 'Gebruiker succesvol verwijderd.',
    'Unable to remove this user.' => 'Kan deze gebruiker niet verwijderen.',
    'Board updated successfully.' => 'Bord succesvol bijgewerkt.',
    'Ready' => 'Klaar',
    'Backlog' => 'In afwachting',
    'Work in progress' => 'In uitvoering',
    'Done' => 'Afgerond',
    'Application version:' => 'Applicatieversie:',
    'Id' => 'Id',
    'Public link' => 'Publieke link',
    'Timezone' => 'Tijdzone',
    'Sorry, I didn\'t find this information in my database!' => 'Sorry, ik heb deze informatie niet gevonden in de database!',
    'Page not found' => 'Pagina niet gevonden',
    'Complexity' => 'Complexiteit',
    'Task limit' => 'Taaklimiet',
    'Task count' => 'Aantal taken',
    'User' => 'Gebruiker',
    'Comments' => 'Commentaar',
    'Comment is required' => 'Commentaar is verplicht',
    'Comment added successfully.' => 'Commentaar succesvol toegevoegd.',
    'Unable to create your comment.' => 'Kan je commentaar niet aanmaken.',
    'Due Date' => 'Vervaldag',
    'Invalid date' => 'Ongeldige datum',
    'Automatic actions' => 'Geautomatiseerde acties',
    'Your automatic action has been created successfully.' => 'Geautomatiseerde actie succesvol aangemaakt.',
    'Unable to create your automatic action.' => 'Kan je automatische actie niet aanmaken.',
    'Remove an action' => 'Een actie verwijderen',
    'Unable to remove this action.' => 'Kan deze actie niet verwijderen.',
    'Action removed successfully.' => 'Actie succesvol verwijderd.',
    'Automatic actions for the project "%s"' => 'Geautomatiseerde acties voor project "%s"',
    'Add an action' => 'Een actie toevoegen',
    'Event name' => 'Naam gebeurtenis',
    'Action' => 'Actie',
    'Event' => 'Gebeurtenis',
    'When the selected event occurs execute the corresponding action.' => 'Wanneer de geselecteerde gebeurtenis plaatsvindt, voer dan de bijbehorende actie uit.',
    'Next step' => 'Volgende stap',
    'Define action parameters' => 'Bepaal actieparameters',
    'Do you really want to remove this action: "%s"?' => 'Wil je deze actie echt verwijderen?: "%s"?',
    'Remove an automatic action' => 'Een automatische actie verwijderen',
    'Assign the task to a specific user' => 'De taak toewijzen aan een specifieke gebruiker',
    'Assign the task to the person who does the action' => 'De taak toewijzen aan de persoon die de actie uitvoert',
    'Duplicate the task to another project' => 'De taak dupliceren in een ander project',
    'Move a task to another column' => 'Een taak verplaatsen naar een andere kolom',
    'Task modification' => 'Aanpassen taak',
    'Task creation' => 'Aanmaken taak',
    'Closing a task' => 'Een taak sluiten',
    'Assign a color to a specific user' => 'Een kleur toewijzen aan een specifieke gebruiker',
    'Position' => 'Positie',
    'Duplicate to project' => 'Dupliceren in een ander project',
    'Duplicate' => 'Dupliceren',
    'Link' => 'Linken',
    'Comment updated successfully.' => 'Commentaar succesvol bijgewerkt.',
    'Unable to update your comment.' => 'Kan je commentaar niet bijwerken.',
    'Remove a comment' => 'Commentaar verwijderen',
    'Comment removed successfully.' => 'Commentaar succesvol verwijderd.',
    'Unable to remove this comment.' => 'Kan dit commentaar niet verwijderen.',
    'Do you really want to remove this comment?' => 'Wil je dit commentaar echt verwijderen?',
    'Current password for the user "%s"' => 'Huidig wachtwoord voor de gebruiker "%s"',
    'The current password is required' => 'Huidig wachtwoord is verplicht',
    'Wrong password' => 'Verkeerd wachtwoord',
    'Unknown' => 'Onbekend',
    'Last logins' => 'Laatste logins',
    'Login date' => 'Logindatum',
    'Authentication method' => 'Authenticatiemethode',
    'IP address' => 'IP-adres',
    'User agent' => 'User agent',
    'Persistent connections' => 'Persistente connecties',
    'No session.' => 'Geen sessie.',
    'Expiration date' => 'Verloopdatum',
    'Remember Me' => 'Onthoud mij',
    'Creation date' => 'Aanmaakdatum',
    'Everybody' => 'Iedereen',
    'Open' => 'Open',
    'Closed' => 'Gesloten',
    'Search' => 'Zoeken',
    'Nothing found.' => 'Niets gevonden.',
    'Due date' => 'Vervaldatum',
    'Description' => 'Omschrijving',
    '%d comments' => '%d commentaren',
    '%d comment' => '%d commentaar',
    'Email address invalid' => 'Ongeldig e-mailadres',
    'Your external account is not linked anymore to your profile.' => 'Je externe account is niet meer gekoppeld aan je profiel.',
    'Unable to unlink your external account.' => 'Kan je externe account niet ontkoppelen.',
    'External authentication failed' => 'Externe authenticatie mislukt',
    'Your external account is linked to your profile successfully.' => 'Je externe account is succesvol gekoppeld aan je profiel.',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Taak succesvol verwijderd.',
    'Unable to remove this task.' => 'Kan deze taak niet verwijderen.',
    'Remove a task' => 'Een taak verwijderen',
    'Do you really want to remove this task: "%s"?' => 'Wil je deze taak echt verwijderen "%s"?',
    'Assign automatically a color based on a category' => 'Automatisch een kleur toewijzen op basis van een categorie',
    'Assign automatically a category based on a color' => 'Automatisch een categorie toewijzen op basis van een kleur',
    'Task creation or modification' => 'Taak aanmaken of wijzigen',
    'Category' => 'Categorie',
    'Category:' => 'Categorie:',
    'Categories' => 'Categorieën',
    'Your category has been created successfully.' => 'Je categorie is succesvol aangemaakt.',
    'This category has been updated successfully.' => 'Je categorie is succesvol bijgewerkt.',
    'Unable to update this category.' => 'Kan deze categorie niet bijwerken.',
    'Remove a category' => 'Categorie verwijderen',
    'Category removed successfully.' => 'Categorie succesvol verwijderd.',
    'Unable to remove this category.' => 'Kan deze categorie niet verwijderen.',
    'Category modification for the project "%s"' => 'Categorie aanpassen voor project "%s"',
    'Category Name' => 'Categorienaam',
    'Add a new category' => 'Categorie toevoegen',
    'Do you really want to remove this category: "%s"?' => 'Wil je deze categorie echt verwijderen: "%s"?',
    'All categories' => 'Alle categorieën',
    'No category' => 'Geen categorie',
    'The name is required' => 'De naam is verplicht',
    'Remove a file' => 'Een bestand verwijderen',
    'Unable to remove this file.' => 'Kan dit bestand niet verwijderen.',
    'File removed successfully.' => 'Bestand succesvol verwijdered.',
    'Attach a document' => 'Document toevoegen',
    'Do you really want to remove this file: "%s"?' => 'Wil je dit bestand echt verwijderen: "%s"?',
    'Attachments' => 'Bijlages',
    'Edit the task' => 'De taak bewerken',
    'Add a comment' => 'Commentaar toevoegen',
    'Edit a comment' => 'Commentaar bewerken',
    'Summary' => 'Samenvatting',
    'Time tracking' => 'Tijdschrijven',
    'Estimate:' => 'Schatting:',
    'Spent:' => 'Besteed:',
    'Do you really want to remove this sub-task?' => 'Wil je deze subtaak echt verwijderen?',
    'Remaining:' => 'Resterend:',
    'hours' => 'uren',
    'estimated' => 'geschat',
    'Sub-Tasks' => 'Subtaken',
    'Add a sub-task' => 'Een subtaak toevoegen',
    'Original estimate' => 'Orginele schatting',
    'Create another sub-task' => 'Nog een subtaak toevoegen',
    'Time spent' => 'Bestede tijd',
    'Edit a sub-task' => 'Subtaak bewerken',
    'Remove a sub-task' => 'Subtaak verwijderen',
    'The time must be a numeric value' => 'De tijd moet een numerieke waarde zijn',
    'Todo' => 'Nog te doen',
    'In progress' => 'In behandeling',
    'Sub-task removed successfully.' => 'Subtaak succesvol verwijderd.',
    'Unable to remove this sub-task.' => 'Kan deze subtaak niet verwijderen.',
    'Sub-task updated successfully.' => 'Subtaak succesvol bijgewerkt.',
    'Unable to update your sub-task.' => 'Kan deze subtaak niet bijwerken.',
    'Unable to create your sub-task.' => 'Kan deze subtaak niet aanmaken.',
    'Maximum size: ' => 'Maximale grootte: ',
    'Display another project' => 'Een ander project weergeven',
    'Created by %s' => 'Aangemaakt door %s',
    'Tasks Export' => 'Taken exporteren',
    'Start Date' => 'Startdatum',
    'Execute' => 'Uitvoeren',
    'Task Id' => 'Taak-ID',
    'Creator' => 'Aangemaakt door',
    'Modification date' => 'Wijzigingsdatum',
    'Completion date' => 'Afgerond op',
    'Clone' => 'Kloon',
    'Project cloned successfully.' => 'Project succesvol gekloond.',
    'Unable to clone this project.' => 'Kan dit project niet klonen.',
    'Enable email notifications' => 'E-mailmeldingen inschakelen',
    'Task position:' => 'Taak positie:',
    'The task #%d has been opened.' => 'Taak #%d is geopend.',
    'The task #%d has been closed.' => 'Taak #%d is gesloten.',
    'Sub-task updated' => 'Subtaak bijgewerkt',
    'Title:' => 'Titel:',
    'Status:' => 'Status:',
    'Assignee:' => 'Toegewezene:',
    'Time tracking:' => 'Tijdschrijven:',
    'New sub-task' => 'Nieuwe subtaak',
    'New attachment added "%s"' => 'Nieuwe bijlage toegevoegd "%s"',
    'New comment posted by %s' => 'Nieuw commentaar geplaatst door "%s"',
    'New comment' => 'Nieuw commentaar',
    'Comment updated' => 'Commentaar bijgewerkt',
    'New subtask' => 'Nieuwe subtaak',
    'I only want to receive notifications for these projects:' => 'Ik wil meldingen ontvangen van de volgende projecten:',
    'view the task on Kanboard' => 'taak bekijken op Kanboard',
    'Public access' => 'Publieke toegang',
    'Disable public access' => 'Publieke toegang uitschakelen',
    'Enable public access' => 'Publieke toegang inschakelen',
    'Public access disabled' => 'Publieke toegang uitgeschakeld',
    'Move the task to another project' => 'Taak verplaatsen naar een ander project',
    'Move to project' => 'Verplaats naar een ander project',
    'Do you really want to duplicate this task?' => 'Wil je deze taak echt dupliceren?',
    'Duplicate a task' => 'Taak dupliceren',
    'External accounts' => 'Externe accounts',
    'Account type' => 'Account type',
    'Local' => 'Lokaal',
    'Remote' => 'Remote',
    'Enabled' => 'Actief',
    'Disabled' => 'Inactief',
    'Login:' => 'Gebruikersnaam:',
    'Full Name:' => 'Naam:',
    'Email:' => 'E-mail:',
    'Notifications:' => 'Meldingen:',
    'Notifications' => 'Meldingen',
    'Account type:' => 'Accounttype:',
    'Edit profile' => 'Profiel aanpassen',
    'Change password' => 'Wachtwoord wijzigen',
    'Password modification' => 'Wijziging wachtwoord',
    'External authentications' => 'Externe authenticatie',
    'Never connected.' => 'Nooit verbonden.',
    'No external authentication enabled.' => 'Geen externe verificatie ingeschakeld.',
    'Password modified successfully.' => 'Wachtwoord succesvol aangepast.',
    'Unable to change the password.' => 'Kan het wachtwoord niet wijzigen.',
    'Change category' => 'Categorie veranderen',
    '%s updated the task %s' => '%s heeft taak %s bijgewerkt',
    '%s opened the task %s' => '%s heeft taak %s geopend',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s heeft taak %s naar positie %d in de kolom "%s" verplaatst',
    '%s moved the task %s to the column "%s"' => '%s heeft taak %s verplaatst naar kolom "%s"',
    '%s created the task %s' => '%s heeft taak %s aangemaakt',
    '%s closed the task %s' => '%s heeft taak %s gesloten',
    '%s created a subtask for the task %s' => '%s heeft een subtaak aangemaakt voor taak %s',
    '%s updated a subtask for the task %s' => '%s heeft een subtaak bijgewerkt voor taak %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Toegewezen aan %s met een schatting van %s/%sh',
    'Not assigned, estimate of %sh' => 'Niet toegewezen, schatting: %sh',
    '%s updated a comment on the task %s' => '%s heeft een commentaar bijgewerkt voor taak %s',
    '%s commented the task %s' => '%s heeft een commentaar geplaatst voor taak %s',
    '%s\'s activity' => 'Activiteiten van %s',
    'RSS feed' => 'RSS-feed',
    '%s updated a comment on the task #%d' => '%s heeft een commentaar bijgewerkt voor taak %d',
    '%s commented on the task #%d' => '%s heeft commentaar geplaatst voor taak %d',
    '%s updated a subtask for the task #%d' => '%s heeft een commentaar bijgewerkt voor subtaak %d',
    '%s created a subtask for the task #%d' => '%s heeft een subtaak aangemaakt voor taak %d',
    '%s updated the task #%d' => '%s heeft taak %d bijgewerkt',
    '%s created the task #%d' => '%s heeft taak %d aangemaakt',
    '%s closed the task #%d' => '%s heeft taak %d gesloten',
    '%s opened the task #%d' => '%s heeft taak %d geopend',
    'Activity' => 'Activiteit',
    'Default values are "%s"' => 'Standaardwaarden zijn "%s"',
    'Default columns for new projects (Comma-separated)' => 'Standaardkolommen voor nieuw projecten (komma-gescheiden)',
    'Task assignee change' => 'Taak toegewezene wijziging',
    '%s changed the assignee of the task #%d to %s' => '%s heeft de toegewezene voor taak %d gewijzigd in %s',
    '%s changed the assignee of the task %s to %s' => '%s heeft de toegewezene voor taak %s gewijzigd in %s',
    'New password for the user "%s"' => 'Nieuw wachtwoord voor de gebruiker "%s"',
    'Choose an event' => 'Kies een gebeurtenis',
    'Create a task from an external provider' => 'Maak een taak aan vanuit een externe provider',
    'Change the assignee based on an external username' => 'De toewijzing wijzigen op basis van een externe gebruikersnaam',
    'Change the category based on an external label' => 'Verander de categorie op basis van een extern label',
    'Reference' => 'Referentie',
    'Label' => 'Label',
    'Database' => 'Database',
    'About' => 'Over',
    'Database driver:' => 'Database-driver:',
    'Board settings' => 'Bord-instellingen',
    'Webhook settings' => 'Webhook-instellingen',
    'Reset token' => 'Token resetten',
    'API endpoint:' => 'API-endpoint:',
    'Refresh interval for personal board' => 'Verversingsinterval voor persoonlijk bord',
    'Refresh interval for public board' => 'Verversingsinterval voor publiek bord',
    'Task highlight period' => 'Taak highlight-periode',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Periode (in seconden) om aan te nemen dat een taak onlangs is gewijzigd (0 om uit te schakelen, standaard 2 dagen)',
    'Frequency in second (60 seconds by default)' => 'Frequentie in seconden (standaard 60)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frequentie in seconden (0 om uit te schakelen, standaard 10)',
    'Application URL' => 'Applicatie-URL',
    'Token regenerated.' => 'Token opnieuw gegenereerd.',
    'Date format' => 'Datumformaat',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO-formaat wordt altijd geaccepteerd, bijvoorbeeld: "%s" en "%s"',
    'New personal project' => 'Nieuw persoonlijk project',
    'This project is personal' => 'Dit project is persoonlijk',
    'Add' => 'Toevoegen',
    'Start date' => 'Startdatum',
    'Time estimated' => 'Geschatte tijd',
    'There is nothing assigned to you.' => 'Er is niets aan jou toegewezen.',
    'My tasks' => 'Mijn taken',
    'Activity stream' => 'Activiteiten',
    'Dashboard' => 'Dashboard',
    'Confirmation' => 'Bevestiging',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Commentaar toevoegen van een externe provider',
    'Project management' => 'Projectmanagement',
    'Columns' => 'Kolommen',
    'Task' => 'Taak',
    'Percentage' => 'Percentage',
    'Number of tasks' => 'Aantal taken',
    'Task distribution' => 'Distributie van taken',
    'Analytics' => 'Analytics',
    'Subtask' => 'Subtaak',
    'User repartition' => 'Gebruikersverdeling',
    'Clone this project' => 'Dit project klonen',
    'Column removed successfully.' => 'Kolom succesvol verwijderd.',
    'Not enough data to show the graph.' => 'Niet genoeg data om de grafiek te laten zien.',
    'Previous' => 'Vorige',
    'The id must be an integer' => 'De ID moet een integer zijn',
    'The project id must be an integer' => 'De project-ID moet een integer zijn',
    'The status must be an integer' => 'De status moet een integer zijn',
    'The subtask id is required' => 'De ID van de subtaak is verplicht',
    'The subtask id must be an integer' => 'De ID van de subtaak moet een integer zijn',
    'The task id is required' => 'De ID van de taak is verplicht',
    'The task id must be an integer' => 'De ID van de taak moet een integer zijn',
    'The user id must be an integer' => 'De ID van de gebruiker moet een integer zijn',
    'This value is required' => 'Deze waarde is verplicht',
    'This value must be numeric' => 'Deze waarde moet numeriek zijn',
    'Unable to create this task.' => 'Kan deze taak niet aanmaken.',
    'Cumulative flow diagram' => 'Cumulatief stroomdiagram',
    'Daily project summary' => 'Dagelijks projectoverzicht',
    'Daily project summary export' => 'Export van het dagelijkse projectoverzicht',
    'Exports' => 'Exports',
    'This export contains the number of tasks per column grouped per day.' => 'Deze export bevat het aantal taken per kolom, gegroepeerd per dag.',
    'Active swimlanes' => 'Actieve swimlanes',
    'Add a new swimlane' => 'Nieuwe swimlane toevoegen',
    'Default swimlane' => 'Standaard swimlane',
    'Do you really want to remove this swimlane: "%s"?' => 'Wil je deze swimlane echt verwijderen: "%s"?',
    'Inactive swimlanes' => 'Inactieve swimlanes',
    'Remove a swimlane' => 'Een swimlane verwijderen',
    'Swimlane modification for the project "%s"' => 'Swimlane aanpassing voor project "%s"',
    'Swimlane removed successfully.' => 'Swimlane succesvol verwijderd.',
    'Swimlanes' => 'Swimlanes',
    'Swimlane updated successfully.' => 'Swimlane succesvol bijgewerkt.',
    'Unable to remove this swimlane.' => 'Kan deze swimlane niet verwijderen.',
    'Unable to update this swimlane.' => 'Kan deze swimlane niet bijwerken.',
    'Your swimlane has been created successfully.' => 'Swimlane succesvol aangemaakt.',
    'Example: "Bug, Feature Request, Improvement"' => 'Voorbeeld: "Bug, Feature Request, Improvement"',
    'Default categories for new projects (Comma-separated)' => 'Standaardcategorieën voor nieuwe projecten (komma-gescheiden)',
    'Integrations' => 'Integraties',
    'Integration with third-party services' => 'Integratie met derde-partij-services',
    'Subtask Id' => 'Subtaak-ID',
    'Subtasks' => 'Subtaken',
    'Subtasks Export' => 'Subtaken exporteren',
    'Task Title' => 'Taaktitel',
    'Untitled' => 'Geen titel',
    'Application default' => 'Standaard voor applicatie',
    'Language:' => 'Taal:',
    'Timezone:' => 'Tijdzone:',
    'All columns' => 'Alle kolommen',
    'Next' => 'Volgende',
    '#%d' => '#%d',
    'All swimlanes' => 'Alle swimlanes',
    'All colors' => 'Alle kleuren',
    'Moved to column %s' => 'Verplaatst naar kolom %s',
    'User dashboard' => 'Gebruikersdashboard',
    'Allow only one subtask in progress at the same time for a user' => 'Een gebruiker mag maar één subtaak tegelijk uitvoeren',
    'Edit column "%s"' => 'Kolom "%s" bewerken',
    'Select the new status of the subtask: "%s"' => 'Selecteer de nieuwe status voor de subtaak: "%s"',
    'Subtask timesheet' => 'Subtaak-timesheet',
    'There is nothing to show.' => 'Er is niets om te laten zien.',
    'Time Tracking' => 'Tijdschrijven',
    'You already have one subtask in progress' => 'Je hebt al een subtaak in behandeling',
    'Which parts of the project do you want to duplicate?' => 'Welke onderdelen van het project wil je dupliceren?',
    'Disallow login form' => 'Inlogformulier blokkeren',
    'Start' => 'Start',
    'End' => 'Eind',
    'Task age in days' => 'Leeftijd van de taak in dagen',
    'Days in this column' => 'Dagen in deze kolom',
    '%dd' => '%dd',
    'Add a new link' => 'Nieuwe link toevoegen',
    'Do you really want to remove this link: "%s"?' => 'Wil je deze link echt verwijderen: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Wil je deze link met taak %d echt verwijderen?',
    'Field required' => 'Veld verplicht',
    'Link added successfully.' => 'Link succesvol toegevoegd.',
    'Link updated successfully.' => 'Link succesvol bijgewerkt.',
    'Link removed successfully.' => 'Link succesvol verwijderd.',
    'Link labels' => 'Linklabels',
    'Link modification' => 'Link-aanpassing',
    'Opposite label' => 'Tegenovergesteld label',
    'Remove a link' => 'Een link verwijderen',
    'The labels must be different' => 'De labels moeten verschillend zijn',
    'There is no link.' => 'Er is geen link.',
    'This label must be unique' => 'Dit label moet uniek zijn',
    'Unable to create your link.' => 'Kan je link niet aanmaken.',
    'Unable to update your link.' => 'Kan je link niet aanpassen.',
    'Unable to remove this link.' => 'Kan je link niet verwijderen.',
    'relates to' => 'is gerelateerd aan',
    'blocks' => 'blokkeert',
    'is blocked by' => 'wordt geblokkeerd door',
    'duplicates' => 'dupliceert',
    'is duplicated by' => 'wordt gedupliceerd door',
    'is a child of' => 'is een kind van',
    'is a parent of' => 'is een ouder van',
    'targets milestone' => 'is nodig voor milestone',
    'is a milestone of' => 'is een milestone voor',
    'fixes' => 'corrigeert',
    'is fixed by' => 'wordt gecorrigeerd door',
    'This task' => 'Deze taak',
    '<1h' => '<1u',
    '%dh' => '%du',
    'Expand tasks' => 'Taken uitklappen',
    'Collapse tasks' => 'Taken inklappen',
    'Expand/collapse tasks' => 'Taken in/uiklappen',
    'Close dialog box' => 'Venster sluiten',
    'Submit a form' => 'Een formulier indienen',
    'Board view' => 'Bordweergave',
    'Keyboard shortcuts' => 'Sneltoetsen',
    'Open board switcher' => 'Open bordwisselaar',
    'Application' => 'Applicatie',
    'Compact view' => 'Compacte weergave',
    'Horizontal scrolling' => 'Horizontaal scrollen',
    'Compact/wide view' => 'Compacte/breedbeeld-weergave',
    'Currency' => 'Valuta',
    'Personal project' => 'Persoonlijk project',
    'AUD - Australian Dollar' => 'AUD - Australische dollar',
    'CAD - Canadian Dollar' => 'CAD - Canadese dollar',
    'CHF - Swiss Francs' => 'CHF - Zwitserse frank',
    'Custom Stylesheet' => 'Aangepast stylesheet',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britse pond',
    'INR - Indian Rupee' => 'INR - Indiaase rupee',
    'JPY - Japanese Yen' => 'JPY - Japanse yen',
    'NZD - New Zealand Dollar' => 'NZD - Nieuw-Zeelandse dollar',
    'PEN - Peruvian Sol' => 'PEN - Peruaanse sol',
    'RSD - Serbian dinar' => 'RSD - Servische dinar',
    'CNY - Chinese Yuan' => 'CNY - Chinese yuan',
    'USD - US Dollar' => 'USD - Amerikaanse dollar',
    'VES - Venezuelan Bolívar' => 'VES - Venezolaanse bolivar',
    'Destination column' => 'Doelkolom',
    'Move the task to another column when assigned to a user' => 'Verplaats de taak naar een andere kolom wanneer deze is toegewezen aan een gebruiker',
    'Move the task to another column when assignee is cleared' => 'Verplaats de taak naar een andere kolom wanneer de toewijzing is verwijderd',
    'Source column' => 'Bronkolom',
    'Transitions' => 'Transities',
    'Executer' => 'Uitvoerder',
    'Time spent in the column' => 'Tijd besteed in de kolom',
    'Task transitions' => 'Taak-transities',
    'Task transitions export' => 'Taak-transities exporteren',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Dit rapport bevat alle kolombewegingen voor elke taak met de datum, de gebruiker en de bestede tijd voor elke overgang.',
    'Currency rates' => 'Wisselkoersen',
    'Rate' => 'Koers',
    'Change reference currency' => 'Referentievaluta wijzigen',
    'Reference currency' => 'Referentievaluta',
    'The currency rate has been added successfully.' => 'De valutakoers is succesvol toegevoegd.',
    'Unable to add this currency rate.' => 'Kan deze valutakoers niet toevoegen.',
    'Webhook URL' => 'Webhook-URL',
    '%s removed the assignee of the task %s' => '%s heeft de ontvanger van de taak %s verwijderd',
    'Information' => 'Informatie',
    'Check two factor authentication code' => 'Controleer de twee-factor authenticatiecode',
    'The two factor authentication code is not valid.' => 'De twee-factor authenticatiecode is niet geldig.',
    'The two factor authentication code is valid.' => 'De twee-factor authenticatiecode is geldig.',
    'Code' => 'Code',
    'Two factor authentication' => 'Twee-factor authenticatie',
    'This QR code contains the key URI: ' => 'Deze QR code bevat de sleutel-URI: ',
    'Check my code' => 'Mijn code controleren',
    'Secret key: ' => 'Geheime sleutel',
    'Test your device' => 'Je device testen',
    'Assign a color when the task is moved to a specific column' => 'Een kleur toewijzen wanneer de taak wordt verplaatst naar een specifieke kolom',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burndown-grafiek',
    'This chart show the task complexity over the time (Work Remaining).' => 'Deze grafiek toont de complexiteit van de taak over de tijd (Work Remaining).',
    'Screenshot taken %s' => 'Screenshot gemaakt %s',
    'Add a screenshot' => 'Screenshot toevoegen',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Maak een screenshot en toets CTRL+V or ⌘+V om het hier te plakken.',
    'Screenshot uploaded successfully.' => 'Screenshot succesvol geüpload.',
    'SEK - Swedish Krona' => 'SEK - Zweedse kroon',
    'Identifier' => 'Identifier',
    'Disable two factor authentication' => 'Twee-factor authenticatie uitschakelen',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Wil je echt de twee-factor authenticatie uitschakelen voor deze gebruiker: "%s"?',
    'Edit link' => 'Link newerken',
    'Start to type task title...' => 'Begin met typen van de taaktitel...',
    'A task cannot be linked to itself' => 'Een taak kan niet aan zichzelf worden gekoppeld',
    'The exact same link already exists' => 'Dezelfde koppeling bestaat al',
    'Recurrent task is scheduled to be generated' => 'Terugkerende taak is gepland om te worden gegenereerd',
    'Score' => 'Score',
    'The identifier must be unique' => 'De identifier moet uniek zijn',
    'This linked task id doesn\'t exists' => 'Deze gekoppelde taak-ID bestaat niet',
    'This value must be alphanumeric' => 'Deze waarde moet alfanumeriek zijn',
    'Edit recurrence' => 'Herhaling bewerken',
    'Generate recurrent task' => 'Terugkerende taak genereren',
    'Trigger to generate recurrent task' => 'Trigger om terugkerende taak te genereren',
    'Factor to calculate new due date' => 'Factor om nieuwe vervaldatum te berekenen',
    'Timeframe to calculate new due date' => 'Tijdsbestek om nieuwe vervaldatum te berekenen',
    'Base date to calculate new due date' => 'Basisdatum om nieuwe vervaldatum te berekenen',
    'Action date' => 'Actiedatum',
    'Base date to calculate new due date: ' => 'Basisdatum voor het berekenen van de nieuwe vervaldatum: ',
    'This task has created this child task: ' => 'Deze taak heeft deze subtaak aangemaakt: ',
    'Day(s)' => 'Dag(en)',
    'Existing due date' => 'Bestaande vervaldatum',
    'Factor to calculate new due date: ' => 'Factor om nieuwe vervaldatum te berekenen: ',
    'Month(s)' => 'Maand(en)',
    'This task has been created by: ' => 'Deze taak is aangemaakt door: ',
    'Recurrent task has been generated:' => 'Terugkerende taak is gegenereerd:',
    'Timeframe to calculate new due date: ' => 'Tijdsbestek om nieuwe vervaldatum te berekenen: ',
    'Trigger to generate recurrent task: ' => 'Trigger om terugkerende taak te genereren: ',
    'When task is closed' => 'Wanneer taak is gesloten',
    'When task is moved from first column' => 'Wanneer de taak is verplaatst van de eerste kolom',
    'When task is moved to last column' => 'Wanneer de taak is verplaatst naar de laatste kolom',
    'Year(s)' => 'Jaar/Jaren',
    'Project settings' => 'Project instellingen',
    'Automatically update the start date' => 'Automatisch de begindatum bijwerken',
    'iCal feed' => 'iCal-feed',
    'Preferences' => 'Voorkeuren',
    'Security' => 'Beveiliging',
    'Two factor authentication disabled' => 'Twee-factor authenticatie uitgeschakeld',
    'Two factor authentication enabled' => 'Twee-factor authenticatie ingeschakeld',
    'Unable to update this user.' => 'Kan deze gebruiker niet bijwerken.',
    'There is no user management for personal projects.' => 'Er is geen gebruikersbeheer voor persoonlijke projecten.',
    'User that will receive the email' => 'Gebruiker die de e-mail ontvangt',
    'Email subject' => 'Onderwerp e-mail',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Een commentaarlog toevoegen bij het verplaatsen van de taak tussen kolommen',
    'Move the task to another column when the category is changed' => 'Verplaats de taak naar een andere kolom wanneer de categorie wordt gewijzigd',
    'Send a task by email to someone' => 'Een taak per e-mail naar iemand verzenden',
    'Reopen a task' => 'Heropen een taak',
    'Notification' => 'Melding',
    '%s moved the task #%d to the first swimlane' => '%s heeft de taak #%d naar de eerste swimlane verplaatst',
    'Swimlane' => 'Swimlane',
    '%s moved the task %s to the first swimlane' => '%s heeft de taak %s naar de eerste swimlane verplaatst',
    '%s moved the task %s to the swimlane "%s"' => '%s heeft taak %s naar swimlane "%s" verplaatst',
    'This report contains all subtasks information for the given date range.' => 'Dit rapport bevat alle subtakeninformatie voor het gegeven datumbereik.',
    'This report contains all tasks information for the given date range.' => 'Dit rapport bevat alle takeninformatie voor het gegeven datumbereik.',
    'Project activities for %s' => 'Projectactiviteiten voor %s',
    'view the board on Kanboard' => 'het bord bekijken op Kanboard',
    'The task has been moved to the first swimlane' => 'De taak is verplaatst naar de eerste swimlane',
    'The task has been moved to another swimlane:' => 'De taak is verplaatst naar een andere swimlane:',
    'New title: %s' => 'Nieuw titel: %s',
    'The task is not assigned anymore' => 'De taak is niet meer toegewezen',
    'New assignee: %s' => 'Nieuwe toegewezene: %s',
    'There is no category now' => 'Er is nu geen categorie',
    'New category: %s' => 'Nieuwe categorie: %s',
    'New color: %s' => 'Nieuwe kleur: %s',
    'New complexity: %d' => 'Nieuwe complexiteit: %d',
    'The due date has been removed' => 'De vervaldatum is verwijderd',
    'There is no description anymore' => 'Er is geen beschrijving meer',
    'Recurrence settings has been modified' => 'Herhalingsinstellingen zijn gewijzigd',
    'Time spent changed: %sh' => 'Bestede tijd gewijzigd: %su',
    'Time estimated changed: %sh' => 'Geschatte tijd gewijzigd: %su',
    'The field "%s" has been updated' => 'Het veld "%s" is bijgewerkt',
    'The description has been modified:' => 'De beschrijving is gewijzigd:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Wil je echt de taak "%s" afsluiten, evenals alle subtaken?',
    'I want to receive notifications for:' => 'Ik wil notificaties ontvangen voor:',
    'All tasks' => 'Alle taken',
    'Only for tasks assigned to me' => 'Alleen voor taken die aan mij zijn toegewezen',
    'Only for tasks created by me' => 'Alleen voor taken die door mij zijn aangemaakt',
    'Only for tasks created by me and tasks assigned to me' => 'Alleen voor taken die door mij zijn aangemaakt en taken die aan mij zijn toegewezen',
    '%%Y-%%m-%%d' => '%%d-%%m-%%Y',
    'Total for all columns' => 'Totaal voor alle kolommen',
    'You need at least 2 days of data to show the chart.' => 'Je hebt gegevens voor minstens 2 dagen nodig om de grafiek te tonen.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Stop timer',
    'Start timer' => 'Start timer',
    'My activity stream' => 'Mijn activiteiten',
    'Search tasks' => 'Zoek taken',
    'Reset filters' => 'Reset filters',
    'My tasks due tomorrow' => 'Mijn taken voor morgen',
    'Tasks due today' => 'Taken voor vandaag',
    'Tasks due tomorrow' => 'Taken voor morgen',
    'Tasks due yesterday' => 'Taken voor gisteren',
    'Closed tasks' => 'Gesloten taken',
    'Open tasks' => 'Open taken',
    'Not assigned' => 'Niet toegewezen',
    'View advanced search syntax' => 'Geavanceerde zoeksyntax bekijken',
    'Overview' => 'Overzicht',
    'Board/Calendar/List view' => 'Bord/Kalender/Lijst weergave',
    'Switch to the board view' => 'Overschakelen naar de bordweergave',
    'Switch to the list view' => 'Overschakelen naar de lijstweergave',
    'Go to the search/filter box' => 'Ga naar het zoek-/filtervak',
    'There is no activity yet.' => 'Er is nog geen activiteit.',
    'No tasks found.' => 'Geen taken gevonden.',
    'Keyboard shortcut: "%s"' => 'Sneltoets: "%s".',
    'List' => 'Lijst',
    'Filter' => 'Filter',
    'Advanced search' => 'Uitgebreid zoeken',
    'Example of query: ' => 'Voorbeeld van zoekopdracht: ',
    'Search by project: ' => 'Zoek op project',
    'Search by column: ' => 'Zoek op kolom',
    'Search by assignee: ' => 'Zoeken op toegewezene: ',
    'Search by color: ' => 'Zoek op kleur',
    'Search by category: ' => 'Zoek op categorie',
    'Search by description: ' => 'Zoek op omschrijving',
    'Search by due date: ' => 'Zoeken op vervaldatum: ',
    'Average time spent in each column' => 'Gemiddelde tijd besteed in elke kolom',
    'Average time spent' => 'Gemiddelde tijd besteed',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Deze grafiek toont de gemiddelde tijd gespendeerd in elke kolom voor de laatste %d taken.',
    'Average Lead and Cycle time' => 'Gemiddelde doorlooptijd en cyclustijd',
    'Average lead time: ' => 'Gemiddelde doorlooptijd: ',
    'Average cycle time: ' => 'Gemiddelde cyclustijd: ',
    'Cycle Time' => 'Cyclustijd',
    'Lead Time' => 'Doorlooptijd',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Deze grafiek toont de gemiddelde doorlooptijd en cyclustijd voor de laatste %d taken door de tijd.',
    'Average time into each column' => 'Gemiddelde tijd in elke kolom',
    'Lead and cycle time' => 'Doorlooptijd en cyclustijd',
    'Lead time: ' => 'Doorlooptijd: ',
    'Cycle time: ' => 'Cyclustijd: ',
    'Time spent in each column' => 'Tijd besteed in elke kolom',
    'The lead time is the duration between the task creation and the completion.' => 'De doorlooptijd is de duur tussen het aanmaken van de taak en de voltooiing.',
    'The cycle time is the duration between the start date and the completion.' => 'De cyclustijd is de tijd tussen de begindatum en de voltooiing.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Als de taak niet is afgesloten, wordt de huidige tijd gebruikt in plaats van de voltooiingsdatum.',
    'Set the start date automatically' => 'De begindatum automatisch instellen',
    'Edit Authentication' => 'Authenticatie bewerken',
    'Remote user' => 'Externe gebruiker',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Externe gebruikers slaan hun wachtwoord niet op in de Kanboard-database, voorbeelden: LDAP-, Google- en Github-accounts.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Als je het vakje "Inlogformulier uitzetten" aanvinkt, worden inloggegevens die zijn ingevoerd in het inlogformulier genegeerd.',
    'Default task color' => 'Standaard taakkleur',
    'This feature does not work with all browsers.' => 'Deze functie werkt niet met alle browsers.',
    'There is no destination project available.' => 'Er is geen doelproject beschikbaar.',
    'Trigger automatically subtask time tracking' => 'Automatisch bijhouden van subtaaktijd triggeren',
    'Include closed tasks in the cumulative flow diagram' => 'Neem afgesloten taken op in het cumulatieve stroomdiagram',
    'Current swimlane: %s' => 'Huidige swimlane: %s',
    'Current column: %s' => 'Huidige kolom: %s',
    'Current category: %s' => 'Huidige categorie: %s',
    'no category' => 'geen categorie',
    'Current assignee: %s' => 'Huidige toegewezene: %s',
    'not assigned' => 'niet toegewezen',
    'Author:' => 'Auteur:',
    'contributors' => 'bijdragers',
    'License:' => 'Licentie:',
    'License' => 'Licentie',
    'Enter the text below' => 'Voer de tekst hieronder in',
    'Start date:' => 'Startdatum:',
    'Due date:' => 'Vervaldatum:',
    'People who are project managers' => 'Mensen die projectbeheerder zijn',
    'People who are project members' => 'Mensen die projectleden zijn',
    'NOK - Norwegian Krone' => 'NOK - Noorse kroon',
    'Show this column' => 'Toon deze kolom',
    'Hide this column' => 'Verberg deze kolom',
    'End date' => 'Einddatum',
    'Users overview' => 'Overzicht gebruikers',
    'Members' => 'Leden',
    'Shared project' => 'Gedeeld project',
    'Project managers' => 'Projectbeheerders',
    'Projects list' => 'Lijst projecten',
    'End date:' => 'Einddatum:',
    'Change task color when using a specific task link' => 'Verander de kleur van een taak wanneer je een specifieke taaklink gebruikt',
    'Task link creation or modification' => 'Taaklink maken of wijzigen',
    'Milestone' => 'Mijlpaal',
    'Reset the search/filter box' => 'Het zoek/filtervak resetten',
    'Documentation' => 'Documentatie',
    'Author' => 'Auteur',
    'Version' => 'Versie',
    'Plugins' => 'Plugins',
    'There is no plugin loaded.' => 'Er is geen plugin geladen.',
    'My notifications' => 'Mijn meldingen',
    'Custom filters' => 'Aangepaste filters',
    'Your custom filter has been created successfully.' => 'Je aangepaste filter is met succes aangemaakt.',
    'Unable to create your custom filter.' => 'Kan je aangepaste filter niet aanmaken.',
    'Custom filter removed successfully.' => 'Aangepast filter met succes verwijderd.',
    'Unable to remove this custom filter.' => 'Kan dit aangepaste filter niet verwijderen.',
    'Edit custom filter' => 'Aangepast filter bewerken',
    'Your custom filter has been updated successfully.' => 'Je aangepaste filter is met succes bijgewerkt.',
    'Unable to update custom filter.' => 'Kan aangepast filter niet bijwerken.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nieuwe bijlage bij taak #%d: %s',
    'New comment on task #%d' => 'Nieuw commentaar op taak #%d',
    'Comment updated on task #%d' => 'Commentaar bijgewerkt op taak #%d',
    'New subtask on task #%d' => 'Nieuwe subtaak op taak #%d',
    'Subtask updated on task #%d' => 'Subtaak bijgewerkt op taak #%d',
    'New task #%d: %s' => 'Nieuwe taak #%d: %s',
    'Task updated #%d' => 'Taak bijgewerkt #%d',
    'Task #%d closed' => 'Taak #%d gesloten',
    'Task #%d opened' => 'Taak #%d geopend',
    'Column changed for task #%d' => 'Kolom gewijzigd voor taak #%d',
    'New position for task #%d' => 'Nieuwe positie voor taak #%d',
    'Swimlane changed for task #%d' => 'Swimlane gewijzigd voor taak #%d',
    'Assignee changed on task #%d' => 'Toegewezene gewijzigd voor taak #%d',
    '%d overdue tasks' => '%d achterstallige taken',
    'No notification.' => 'Geen melding.',
    'Mark all as read' => 'Markeer alles als gelezen',
    'Mark as read' => 'Markeer als gelezen',
    'Total number of tasks in this column across all swimlanes' => 'Totaal aantal taken in deze kolom in alle swimlanes',
    'Collapse swimlane' => 'Voeg swimlane samen',
    'Expand swimlane' => 'Breid swimlane uit',
    'Add a new filter' => 'Een nieuw filter toevoegen',
    'Share with all project members' => 'Delen met alle projectleden',
    'Shared' => 'Gedeeld',
    'Owner' => 'Eigenaar',
    'Unread notifications' => 'Ongelezen meldingen',
    'Notification methods:' => 'Kennisgevingsmethoden:',
    'Unable to read your file' => 'Kan je bestand niet lezen',
    '%d task(s) have been imported successfully.' => '%d taak (taken) is (zijn) met succes geïmporteerd.',
    'Nothing has been imported!' => 'Er is niets geïmporteerd!',
    'Import users from CSV file' => 'Gebruikers importeren uit CSV-bestand',
    '%d user(s) have been imported successfully.' => '%d gebruiker(s) zijn succesvol geïmporteerd.',
    'Comma' => 'Komma',
    'Semi-colon' => 'Punt-komma',
    'Tab' => 'Tab',
    'Vertical bar' => 'Verticale balk',
    'Double Quote' => 'Dubbele aanhalingstekens',
    'Single Quote' => 'Enkele aanhalingstekens',
    '%s attached a file to the task #%d' => '%s heeft een bestand toegevoegd aan de taak #%d',
    'There is no column or swimlane activated in your project!' => 'Er is geen kolom of swimlane geactiveerd in je project!',
    'Append filter (instead of replacement)' => 'Voeg filter toe (in plaats van vervangen)',
    'Append/Replace' => 'Toevoegen/vervangen',
    'Append' => 'Toevoegen',
    'Replace' => 'Vervang',
    'Import' => 'Importeer',
    'Change sorting' => 'Sortering wijzigen',
    'Tasks Importation' => 'Taken importeren',
    'Delimiter' => 'Scheidingsteken',
    'Enclosure' => 'Omsluiting',
    'CSV File' => 'CSV bestand',
    'Instructions' => 'Instructies',
    'Your file must use the predefined CSV format' => 'Je bestand moet de vooraf gedefinieerde CSV-indeling gebruiken',
    'Your file must be encoded in UTF-8' => 'Je bestand moet gecodeerd zijn in UTF-8',
    'The first row must be the header' => 'De eerste rij moet de koptekst zijn',
    'Duplicates are not verified for you' => 'Duplicaten worden niet voor je gecontroleerd',
    'The due date must use the ISO format: YYYY-MM-DD' => 'De vervaldatum moet het ISO-formaat gebruiken: JJJJ-MM-DD',
    'Download CSV template' => 'CSV-sjabloon downloaden',
    'No external integration registered.' => 'Geen externe integratie geregistreerd.',
    'Duplicates are not imported' => 'Duplicaten worden niet geïmporteerd',
    'Usernames must be lowercase and unique' => 'Gebruikersnamen moeten kleine letters en uniek zijn',
    'Passwords will be encrypted if present' => 'Wachtwoorden worden gecodeerd indien aanwezig',
    '%s attached a new file to the task %s' => '%s heeft een nieuw bestand toegevoegd aan de taak %s',
    'Link type' => 'Type koppeling',
    'Assign automatically a category based on a link' => 'Automatisch een categorie toewijzen op basis van een link',
    'BAM - Konvertible Mark' => 'BAM - converteerbare mark',
    'Assignee Username' => 'Gebruikersnaam ontvanger',
    'Assignee Name' => 'Naam toewijzing',
    'Groups' => 'Groepen',
    'Members of %s' => 'Leden van %s',
    'New group' => 'Nieuwe groep',
    'Group created successfully.' => 'Groep succesvol aangemaakt.',
    'Unable to create your group.' => 'Kan je groep niet aanmaken.',
    'Edit group' => 'Groep bewerken',
    'Group updated successfully.' => 'Groep bijgewerkt.',
    'Unable to update your group.' => 'Kan je groep niet bijwerken.',
    'Add group member to "%s"' => 'Groepslid toevoegen aan "%s"',
    'Group member added successfully.' => 'Groepslid toegevoegd.',
    'Unable to add group member.' => 'Kan geen groepslid toevoegen.',
    'Remove user from group "%s"' => 'Gebruiker verwijderd uit groep "%s"',
    'User removed successfully from this group.' => 'Gebruiker succesvol verwijderd uit deze groep.',
    'Unable to remove this user from the group.' => 'Kan deze gebruiker niet uit de groep verwijderen.',
    'Remove group' => 'Verwijder groep',
    'Group removed successfully.' => 'Groep succesvol verwijderd.',
    'Unable to remove this group.' => 'Kan deze groep niet verwijderen.',
    'Project Permissions' => 'Projectmachtigingen',
    'Manager' => 'Manager',
    'Project Manager' => 'Projectbeheerder',
    'Project Member' => 'Projectlid',
    'Project Viewer' => 'Project-viewer',
    'Your account is locked for %d minutes' => 'Je account is geblokkeerd voor %d minuten',
    'Invalid captcha' => 'Ongeldige captcha',
    'The name must be unique' => 'De naam moet uniek zijn',
    'View all groups' => 'Alle groepen weergeven',
    'There is no user available.' => 'Er is geen gebruiker beschikbaar.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Wil je echt de gebruiker "%s" verwijderen uit de groep "%s"?',
    'There is no group.' => 'Er is geen groep.',
    'Add group member' => 'Groepslid toevoegen',
    'Do you really want to remove this group: "%s"?' => 'Wil je deze groep echt verwijderen? "%s"?',
    'There is no user in this group.' => 'Er is geen gebruiker in deze groep.',
    'Permissions' => 'Rechten',
    'Allowed Users' => 'Toegestane gebruikers',
    'No specific user has been allowed.' => 'Er is geen specifieke gebruiker toegestaan.',
    'Role' => 'Rol',
    'Enter user name...' => 'Voer gebruikersnaam in...',
    'Allowed Groups' => 'Toegestane groepen',
    'No group has been allowed.' => 'Er is geen groep toegestaan.',
    'Group' => 'Groep',
    'Group Name' => 'Naam groep',
    'Enter group name...' => 'Naam van groep invoeren...',
    'Role:' => 'Rol:',
    'Project members' => 'Projectleden',
    '%s mentioned you in the task #%d' => '%s noemde jou in de taak #%d',
    '%s mentioned you in a comment on the task #%d' => '%s noemde jou in een commentaar op de taak #%d',
    'You were mentioned in the task #%d' => 'Je werd genoemd in de taak #%d',
    'You were mentioned in a comment on the task #%d' => 'Je werd genoemd in een commentaar op de taak #%d',
    'Estimated hours: ' => 'Geschatte uren: ',
    'Actual hours: ' => 'Werkelijke uren: ',
    'Hours Spent' => 'Bestede uren',
    'Hours Estimated' => 'Geschatte uren',
    'Estimated Time' => 'Geschatte tijd',
    'Actual Time' => 'Werkelijke tijd',
    'Estimated vs actual time' => 'Geschatte vs. werkelijke tijd',
    'RUB - Russian Ruble' => 'RUB - Russische roebel',
    'Assign the task to the person who does the action when the column is changed' => 'Wijs de taak toe aan de persoon die de actie uitvoert wanneer de kolom wordt gewijzigd',
    'Close a task in a specific column' => 'Sluit een taak in een specifieke kolom',
    'Time-based One-time Password Algorithm' => 'Tijdgebaseerd algoritme voor eenmalig wachtwoord',
    'Two-Factor Provider: ' => 'Provider met twee factoren: ',
    'Disable two-factor authentication' => 'Twee-factor authenticatie uitschakelen',
    'Enable two-factor authentication' => 'Twee-factor authenticatie inschakelen',
    'There is no integration registered at the moment.' => 'Er is momenteel geen integratie geregistreerd.',
    'Password Reset for Kanboard' => 'Wachtwoord opnieuw instellen voor Kanboard',
    'Forgot password?' => 'Wachtwoord vergeten?',
    'Enable "Forget Password"' => '"Wachtwoord vergeten" inschakelen',
    'Password Reset' => 'Wachtwoord opnieuw instellen',
    'New password' => 'Nieuw wachtwoord',
    'Change Password' => 'Wijzig wachtwoord',
    'To reset your password click on this link:' => 'Klik op deze link om je wachtwoord opnieuw in te stellen:',
    'Last Password Reset' => 'Laatste wachtwoordverandering',
    'The password has never been reinitialized.' => 'Het wachtwoord is nooit opnieuw geïnitialiseerd.',
    'Creation' => 'Aanmaak',
    'Expiration' => 'Vervaldatum',
    'Password reset history' => 'Geschiedenis wachtwoordwijzigingen',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alle taken van de kolom "%s" en de swimlane "%s" zijn met succes afgesloten.',
    'Do you really want to close all tasks of this column?' => 'Wil je echt alle taken van deze kolom sluiten?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d taak (taken) in de kolom "%s" en de swimlane "%s" zullen worden gesloten.',
    'Close all tasks in this column and this swimlane' => 'Sluit alle taken in deze kolom en deze swimlane',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Geen enkele plugin heeft een projectnotificatiemethode geregistreerd. Je kunt nog steeds individuele meldingen configureren in je gebruikersprofiel.',
    'My dashboard' => 'Mijn dashboard',
    'My profile' => 'Mijn profiel',
    'Project owner: ' => 'Project eigenaar: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'De projectidentificatie is optioneel en moet alfanumeriek zijn, bijvoorbeeld: MYPROJECT.',
    'Project owner' => 'Project eigenaar',
    'Personal projects do not have users and groups management.' => 'Persoonlijke projecten hebben geen gebruikers- en groepenbeheer.',
    'There is no project member.' => 'Er is geen projectlid.',
    'Priority' => 'Prioriteit',
    'Task priority' => 'Taak prioriteit',
    'General' => 'Algemeen',
    'Dates' => 'Datums',
    'Default priority' => 'Standaard prioriteit',
    'Lowest priority' => 'Laagste prioriteit',
    'Highest priority' => 'Hoogste prioriteit',
    'Close a task when there is no activity' => 'Een taak sluiten als er geen activiteit is',
    'Duration in days' => 'Duur in dagen',
    'Send email when there is no activity on a task' => 'Een e-mail sturen wanneer er geen activiteit is voor een taak',
    'Unable to fetch link information.' => 'Kan geen linkinformatie ophalen.',
    'Daily background job for tasks' => 'Dagelijkse achtergrondtaak voor taken',
    'Auto' => 'Auto',
    'Related' => 'Gerelateerd',
    'Attachment' => 'Bijlage',
    'Web Link' => 'Weblink',
    'External links' => 'Externe links',
    'Add external link' => 'Externe link toevoegen',
    'Type' => 'Type',
    'Dependency' => 'Afhankelijkheid',
    'Add internal link' => 'Interne link toevoegen',
    'Add a new external link' => 'Nieuwe externe link toevoegen',
    'Edit external link' => 'Externe link bewerken',
    'External link' => 'Externe link',
    'Copy and paste your link here...' => 'Kopieer en plak je link hier...',
    'URL' => 'URL',
    'Internal links' => 'Interne koppelingen',
    'Assign to me' => 'Aan mij toewijzen',
    'Me' => 'Mij',
    'Do not duplicate anything' => 'Niets dupliceren',
    'Projects management' => 'Projecten beheren',
    'Users management' => 'Gebruikers beheren',
    'Groups management' => 'Groepen beheren',
    'Create from another project' => 'Aanmaken vanuit een ander project',
    'open' => 'open',
    'closed' => 'gesloten',
    'Priority:' => 'Prioriteit:',
    'Reference:' => 'Referentie:',
    'Complexity:' => 'Complexiteit:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Kolom:',
    'Position:' => 'Positie:',
    'Creator:' => 'Aanmaker:',
    'Time estimated:' => 'Ingeschatte tijd:',
    '%s hours' => '%s uur',
    'Time spent:' => 'Tijd besteed:',
    'Created:' => 'Aangemaakt:',
    'Modified:' => 'Gewijzigd:',
    'Completed:' => 'Afgerond:',
    'Started:' => 'Begonnen:',
    'Moved:' => 'Verplaatst:',
    'Task #%d' => 'Taak #%d',
    'Time format' => 'Tijd formaat',
    'Start date: ' => 'Begindatum: ',
    'End date: ' => 'Einddatum: ',
    'New due date: ' => 'Nieuwe einddatum: ',
    'Start date changed: ' => 'Startdatum gewijzigd: ',
    'Disable personal projects' => 'Persoonlijke projecten uitschakelen',
    'Do you really want to remove this custom filter: "%s"?' => 'Wil je deze aangepaste filter echt verwijderen: "%s"?',
    'Remove a custom filter' => 'Een aangepast filter verwijderen',
    'User activated successfully.' => 'Gebruiker succesvol geactiveerd.',
    'Unable to enable this user.' => 'Kan deze gebruiker niet inschakelen.',
    'User disabled successfully.' => 'Gebruiker uitgeschakeld.',
    'Unable to disable this user.' => 'Kan deze gebruiker niet uitschakelen.',
    'All files have been uploaded successfully.' => 'Alle bestanden zijn succesvol geüpload.',
    'The maximum allowed file size is %sB.' => 'De maximaal toegestane bestandsgrootte is %sB.',
    'Drag and drop your files here' => 'Sleep je bestanden hierheen',
    'choose files' => 'kies bestanden',
    'View profile' => 'Profiel bekijken',
    'Two Factor' => 'Twee-factor',
    'Disable user' => 'Gebruiker uitschakelen',
    'Do you really want to disable this user: "%s"?' => 'Wil je deze gebruiker echt uitschakelen: "%s"?',
    'Enable user' => 'Gebruiker inschakelen',
    'Do you really want to enable this user: "%s"?' => 'Wil je deze gebruiker echt inschakelen: "%s"?',
    'Download' => 'Downloaden',
    'Uploaded: %s' => 'Geüpload: %s',
    'Size: %s' => 'Grootte: %s',
    'Uploaded by %s' => 'Geüpload door %s',
    'Filename' => 'Bestandsnaam',
    'Size' => 'Grootte',
    'Column created successfully.' => 'Kolom succesvol aangemaakt.',
    'Another column with the same name exists in the project' => 'Een andere kolom met dezelfde naam bestaat in het project',
    'Default filters' => 'Standaard filters',
    'Your board doesn\'t have any columns!' => 'Je bord heeft geen kolommen!',
    'Change column position' => 'Kolompositie wijzigen',
    'Switch to the project overview' => 'Ga naar het projectoverzicht',
    'User filters' => 'Gebruikersfilters',
    'Category filters' => 'Categoriefilters',
    'Upload a file' => 'Een bestand uploaden',
    'View file' => 'Bestand bekijken',
    'Last activity' => 'Laatste activiteit',
    'Change subtask position' => 'Positie van subtaak wijzigen',
    'This value must be greater than %d' => 'Deze waarde moet groter zijn dan %d',
    'Another swimlane with the same name exists in the project' => 'Er bestaat een andere swimlane met dezelfde naam in het project',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Voorbeeld: https://example.kanboard.org/ (gebruikt om absolute URL\'s te genereren)',
    'Actions duplicated successfully.' => 'Acties succesvol gedupliceerd.',
    'Unable to duplicate actions.' => 'Kan acties niet dupliceren.',
    'Add a new action' => 'Voeg een nieuwe actie toe',
    'Import from another project' => 'Importeren vanuit een ander project',
    'There is no action at the moment.' => 'Er is op dit moment geen actie.',
    'Import actions from another project' => 'Importeer acties van een ander project',
    'There is no available project.' => 'Er is geen project beschikbaar.',
    'Local File' => 'Lokaal bestand',
    'Configuration' => 'Configuratie',
    'PHP version:' => 'PHP versie:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS versie:',
    'Database version:' => 'Database versie:',
    'Browser:' => 'Browser:',
    'Task view' => 'Taak bekijken',
    'Edit task' => 'Taak bewerken',
    'Edit description' => 'Beschrijving bewerken',
    'New internal link' => 'Nieuwe interne link',
    'Display list of keyboard shortcuts' => 'Lijst met sneltoetsen weergeven',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Mijn avatar uploaden',
    'Remove my image' => 'Mijn afbeelding verwijderen',
    'The OAuth2 state parameter is invalid' => 'De OAuth2-statusparameter is ongeldig',
    'User not found.' => 'Gebruiker niet gevonden.',
    'Search in activity stream' => 'Zoeken in activiteitenstroom',
    'My activities' => 'Mijn activiteiten',
    'Activity until yesterday' => 'Activiteit tot gisteren',
    'Activity until today' => 'Activiteit tot vandaag',
    'Search by creator: ' => 'Zoeken op maker: ',
    'Search by creation date: ' => 'Zoeken op aanmaakdatum: ',
    'Search by task status: ' => 'Zoeken op taakstatus: ',
    'Search by task title: ' => 'Zoeken op taaktitel: ',
    'Activity stream search' => 'Zoeken op activiteitenstroom',
    'Projects where "%s" is manager' => 'Projecten waar "%s" manager is',
    'Projects where "%s" is member' => 'Projecten waar "%s" lid van is',
    'Open tasks assigned to "%s"' => 'Open taken toegewezen aan "%s',
    'Closed tasks assigned to "%s"' => 'Gesloten taken toegewezen aan "%s',
    'Assign automatically a color based on a priority' => 'Automatisch een kleur toewijzen op basis van prioriteit',
    'Overdue tasks for the project(s) "%s"' => 'Achterstallige taken voor het project (de projecten) "%s".',
    'Upload files' => 'Bestanden uploaden',
    'Installed Plugins' => 'Geïnstalleerde plugins',
    'Plugin Directory' => 'Plugin map',
    'Plugin installed successfully.' => 'Plugin met succes geïnstalleerd.',
    'Plugin updated successfully.' => 'Plugin bijgewerkt.',
    'Plugin removed successfully.' => 'Plugin met succes verwijderd.',
    'Subtask converted to task successfully.' => 'Subtaak met succes geconverteerd naar taak.',
    'Unable to convert the subtask.' => 'Kan de subtaak niet converteren.',
    'Unable to extract plugin archive.' => 'Plugin-archief kan niet worden uitgepakt.',
    'Plugin not found.' => 'Plugin niet gevonden.',
    'You don\'t have the permission to remove this plugin.' => 'Je hebt geen toestemming om deze plugin te verwijderen.',
    'Unable to download plugin archive.' => 'Kan het plugin-archief niet downloaden.',
    'Unable to write temporary file for plugin.' => 'Kan geen tijdelijk bestand voor plugin schrijven.',
    'Unable to open plugin archive.' => 'Kan het plugin archief niet openen.',
    'There is no file in the plugin archive.' => 'Er is geen bestand in het plugin archief.',
    'Create tasks in bulk' => 'Taken in bulk aanmaken',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Je Kanboard-instantie is niet geconfigureerd om plugins te installeren vanuit de gebruikersinterface.',
    'There is no plugin available.' => 'Er is geen plugin beschikbaar.',
    'Install' => 'Installeer',
    'Update' => 'Bijwerken',
    'Up to date' => 'Up to date',
    'Not available' => 'Niet beschikbaar',
    'Remove plugin' => 'Plugin verwijderen',
    'Do you really want to remove this plugin: "%s"?' => 'Wil je deze plugin echt verwijderen: "%s"?',
    'Uninstall' => 'Verwijder',
    'Listing' => 'Lijst',
    'Metadata' => 'Metagegevens',
    'Manage projects' => 'Projecten beheren',
    'Convert to task' => 'Omzetten naar taak',
    'Convert sub-task to task' => 'Subtaak omzetten naar taak',
    'Do you really want to convert this sub-task to a task?' => 'Wil je deze subtaak echt omzetten naar een taak?',
    'My task title' => 'Mijn taak titel',
    'Enter one task by line.' => 'Per regel een taak invoeren.',
    'Number of failed login:' => 'Aantal mislukte aanmeldingen:',
    'Account locked until:' => 'Account vergrendeld tot:',
    'Email settings' => 'E-mailinstellingen',
    'Email sender address' => 'E-mailadres afzender',
    'Email transport' => 'E-mail transport',
    'Webhook token' => 'Webhook token',
    'Project tags management' => 'Project tags beheer',
    'Tag created successfully.' => 'Tag met succes aangemaakt.',
    'Unable to create this tag.' => 'Kan deze tag niet aanmaken.',
    'Tag updated successfully.' => 'Tag met succes bijgewerkt.',
    'Unable to update this tag.' => 'Kan deze tag niet bijwerken.',
    'Tag removed successfully.' => 'Tag met succes verwijderd.',
    'Unable to remove this tag.' => 'Kan deze tag niet verwijderen.',
    'Global tags management' => 'Beheer globale tags',
    'Tags' => 'Tags',
    'Tags management' => 'Beheer tags',
    'Add new tag' => 'Voeg een nieuwe tag toe',
    'Edit a tag' => 'Een tag bewerken',
    'Project tags' => 'Projecttags',
    'There is no specific tag for this project at the moment.' => 'Er zijn geen tags gedefinieerd voor dit project.',
    'Tag' => 'Tag',
    'Remove a tag' => 'Een tag verwijderen',
    'Do you really want to remove this tag: "%s"?' => 'Wil je deze tag echt verwijderen: "%s"?',
    'Global tags' => 'Globale tags',
    'There is no global tag at the moment.' => 'Er is momenteel geen globale tag.',
    'This field cannot be empty' => 'Dit veld kan niet leeg zijn',
    'Close a task when there is no activity in a specific column' => 'Een taak sluiten wanneer er geen activiteit is in een specifieke kolom',
    '%s removed a subtask for the task #%d' => '%s verwijderde een subtaak voor de taak #%d',
    '%s removed a comment on the task #%d' => '%s heeft een commentaar bij taak #%d verwijderd',
    'Comment removed on task #%d' => 'Commentaar bij taak #%d verwijderd',
    'Subtask removed on task #%d' => 'Subtaak verwijderd voor taak #%d',
    'Hide tasks in this column in the dashboard' => 'Verberg taken in deze kolom in het dashboard',
    '%s removed a comment on the task %s' => '%s heeft een commentaar bij taak %s verwijderd',
    '%s removed a subtask for the task %s' => '%s heeft een subtaak verwijderd voor de taak %s',
    'Comment removed' => 'Commentaar verwijderd',
    'Subtask removed' => 'Subtaak verwijderd',
    '%s set a new internal link for the task #%d' => '%s heeft een nieuwe interne link geplaatst voor de taak #%d',
    '%s removed an internal link for the task #%d' => '%s verwijderde een interne link voor de taak #%d',
    'A new internal link for the task #%d has been defined' => 'Een nieuwe interne link voor de taak #%d is gedefinieerd.',
    'Internal link removed for the task #%d' => 'Interne link verwijderd voor de taak #%d',
    '%s set a new internal link for the task %s' => '%s heeft een nieuwe interne link ingesteld voor de taak %s',
    '%s removed an internal link for the task %s' => '%s heeft een interne link verwijderd voor de taak %s',
    'Automatically set the due date on task creation' => 'Stel automatisch de vervaldatum in bij het aanmaken van een taak',
    'Move the task to another column when closed' => 'Verplaats de taak naar een andere kolom wanneer deze is gesloten',
    'Move the task to another column when not moved during a given period' => 'Verplaats de taak naar een andere kolom wanneer deze niet is verplaatst gedurende een bepaalde periode',
    'Dashboard for %s' => 'Dashboard voor %s',
    'Tasks overview for %s' => 'Taken overzicht voor %s',
    'Subtasks overview for %s' => 'Subtaken overzicht voor %s',
    'Projects overview for %s' => 'Projecten overzicht voor %s',
    'Activity stream for %s' => 'Activiteitenstroom voor %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Wijs een kleur toe wanneer de taak wordt verplaatst naar een specifieke swimlane',
    'Assign a priority when the task is moved to a specific swimlane' => 'Prioriteit toekennen wanneer de taak wordt verplaatst naar een specifieke swimlane',
    'User unlocked successfully.' => 'Gebruiker succesvol ontgrendeld.',
    'Unable to unlock the user.' => 'Kan de gebruiker niet ontgrendelen.',
    'Move a task to another swimlane' => 'Een taak naar een andere swimlane verplaatsen',
    'Creator Name' => 'Naam aanmaker',
    'Time spent and estimated' => 'Tijd besteed en geschat',
    'Move position' => 'Positie verplaatsen',
    'Move task to another position on the board' => 'Verplaats taak naar een andere positie op het bord',
    'Insert before this task' => 'Invoegen vóór deze taak',
    'Insert after this task' => 'Invoegen na deze taak',
    'Unlock this user' => 'Ontgrendel deze gebruiker',
    'Custom Project Roles' => 'Aangepaste projectrollen',
    'Add a new custom role' => 'Een nieuwe aangepaste rol toevoegen',
    'Restrictions for the role "%s"' => 'Beperkingen voor de rol "%s".',
    'Add a new project restriction' => 'Een nieuwe projectbeperking toevoegen',
    'Add a new drag and drop restriction' => 'Een nieuwe slepen-en-neerzetten beperking toevoegen',
    'Add a new column restriction' => 'Een nieuwe kolombeperking toevoegen',
    'Edit this role' => 'Deze rol bewerken',
    'Remove this role' => 'Deze role verwijderen',
    'There is no restriction for this role.' => 'Er is geen beperking voor deze rol.',
    'Only moving task between those columns is permitted' => 'Alleen het verplaatsen van taken tussen deze kolommen is toegestaan',
    'Close a task in a specific column when not moved during a given period' => 'Sluit een taak in een specifieke kolom als deze niet is verplaatst gedurende een bepaalde periode',
    'Edit columns' => 'Kolommen berwerken',
    'The column restriction has been created successfully.' => 'De kolombeperking is succesvol aangemaakt.',
    'Unable to create this column restriction.' => 'Kan deze kolombeperking niet aanmaken.',
    'Column restriction removed successfully.' => 'Kolombeperking succesvol verwijderd.',
    'Unable to remove this restriction.' => 'Kan deze beperking niet verwijderen.',
    'Your custom project role has been created successfully.' => 'Je aangepaste projectrol is succesvol aangemaakt.',
    'Unable to create custom project role.' => 'Kan aangepaste projectrol niet aanmaken.',
    'Your custom project role has been updated successfully.' => 'Je aangepaste projectrol is succesvol bijgewerkt.',
    'Unable to update custom project role.' => 'Kan aangepaste projectrol niet bijwerken.',
    'Custom project role removed successfully.' => 'Aangepaste projectrol succesvol verwijderd.',
    'Unable to remove this project role.' => 'Kan deze projectrol niet verwijderen.',
    'The project restriction has been created successfully.' => 'De projectrestrictie is succesvol aangemaakt.',
    'Unable to create this project restriction.' => 'Kan deze projectrestrictie niet aanmaken.',
    'Project restriction removed successfully.' => 'Projectbeperking succesvol verwijderd.',
    'You cannot create tasks in this column.' => 'Je kunt geen taken aanmaken in deze kolom.',
    'Task creation is permitted for this column' => 'Taken aanmaken is toegestaan voor deze kolom.',
    'Closing or opening a task is permitted for this column' => 'Een taak sluiten of openen is toegestaan voor deze kolom.',
    'Task creation is blocked for this column' => 'Taak aanmaken is geblokkeerd voor deze kolom',
    'Closing or opening a task is blocked for this column' => 'Een taak sluiten of openen is geblokkeerd voor deze kolom',
    'Task creation is not permitted' => 'Taken aanmaken is niet toegestaan',
    'Closing or opening a task is not permitted' => 'Een taak sluiten of openen is niet toegestaan',
    'New drag and drop restriction for the role "%s"' => 'Nieuwe slepen en neerzetten beperking voor de rol "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Mensen die behoren tot deze rol kunnen alleen taken verplaatsen tussen de bron- en bestemmingskolom.',
    'Remove a column restriction' => 'Een kolombeperking verwijderen',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Wil je deze kolombeperking echt verwijderen? "%s" naar "%s"?',
    'New column restriction for the role "%s"' => 'Nieuwe kolombeperking voor de rol "%s".',
    'Rule' => 'Regel',
    'Do you really want to remove this column restriction?' => 'Wil je deze kolombeperking echt verwijderen?',
    'Custom roles' => 'Aangepaste rollen',
    'New custom project role' => 'Nieuwe aangepaste projectrol',
    'Edit custom project role' => 'Aangepaste projectrol bewerken',
    'Remove a custom role' => 'Een aangepaste rol verwijderen',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Wil je deze aangepaste rol echt verwijderen: "%s"? Alle mensen die aan deze rol zijn toegewezen worden projectlid.',
    'There is no custom role for this project.' => 'Er is geen aangepaste rol voor dit project.',
    'New project restriction for the role "%s"' => 'Nieuwe projectbeperking voor de rol "%s".',
    'Restriction' => 'Beperking',
    'Remove a project restriction' => 'Een projectbeperking verwijderen',
    'Do you really want to remove this project restriction: "%s"?' => 'Wil je deze projectrestrictie echt verwijderen: "%s"?',
    'Duplicate to multiple projects' => 'Dupliceren naar meerdere projecten',
    'This field is required' => 'Dit veld is verplicht',
    'Moving a task is not permitted' => 'Een taak verplaatsen is niet toegestaan',
    'This value must be in the range %d to %d' => 'Deze waarde moet in het bereik %d tot %d liggen',
    'You are not allowed to move this task.' => 'Je mag deze taak niet verplaatsen.',
    'API User Access' => 'API-gebruikerstoegang',
    'Preview' => 'Voorbeeld',
    'Write' => 'Schrijven',
    'Write your text in Markdown' => 'Schrijf je tekst in Markdown',
    'No personal API access token registered.' => 'Geen persoonlijk API toegangstoken geregistreerd.',
    'Your personal API access token is "%s"' => 'Je persoonlijke API toegang token is "%s".',
    'Remove your token' => 'Verwijder je token',
    'Generate a new token' => 'Genereer een nieuw token',
    'Showing %d-%d of %d' => 'Weergave %d-%d van %d',
    'Outgoing Emails' => 'Uitgaande e-mails',
    'Add or change currency rate' => 'Valutakoers toevoegen of wijzigen',
    'Reference currency: %s' => 'Referentievaluta: %s',
    'Add custom filters' => 'Nieuw aangepast filter toevoegen',
    'Export' => 'Exporteren',
    'Add link label' => 'Linklabel toevoegen',
    'Incompatible Plugins' => 'Onverenigbare plugins',
    'Compatibility' => 'Compatibiliteit',
    'Permissions and ownership' => 'Rechten en eigendom',
    'Priorities' => 'Prioriteiten',
    'Close this window' => 'Dit scherm sluiten',
    'Unable to upload this file.' => 'Kan dit bestand niet uploaden.',
    'Import tasks' => 'Taken importeren',
    'Choose a project' => 'Kies een project',
    'Profile' => 'Profiel',
    'Application role' => 'Rol toepassing',
    '%d invitations were sent.' => '%d uitnodigingen zijn verzonden.',
    '%d invitation was sent.' => '%d uitnodigingen verzonden.',
    'Unable to create this user.' => 'Kan deze gebruiker niet aanmaken.',
    'Kanboard Invitation' => 'Kanboard uitnodiging',
    'Visible on dashboard' => 'Zichtbaar op dashboard',
    'Created at:' => 'Aangemaakt op:',
    'Updated at:' => 'Bijgewerkt op:',
    'There is no custom filter.' => 'Er is geen aangepaste filter.',
    'New User' => 'Nieuwe gebruiker',
    'Authentication' => 'Authenticatie',
    'If checked, this user will use a third-party system for authentication.' => 'Als deze optie is aangevinkt, zal deze gebruiker een systeem van derden gebruiken voor verificatie.',
    'The password is necessary only for local users.' => 'Het wachtwoord is alleen nodig voor lokale gebruikers.',
    'You have been invited to register on Kanboard.' => 'Je bent uitgenodigd om je te registreren op Kanboard.',
    'Click here to join your team' => 'Klik hier om lid te worden van je team',
    'Invite people' => 'Nodig personen uit',
    'Emails' => 'E-mails',
    'Enter one email address by line.' => 'Voer één e-mailadres per regel in.',
    'Add these people to this project' => 'Voeg deze mensen toe aan dit project',
    'Add this person to this project' => 'Voeg deze persoon toe aan dit project',
    'Sign-up' => 'Aanmelden',
    'Credentials' => 'Gegevens',
    'New user' => 'Nieuwe gebruiker',
    'This username is already taken' => 'Deze gebruikersnaam is al gebruikt',
    'Your profile must have a valid email address.' => 'Je profiel moet een geldig e-mailadres hebben.',
    'TRL - Turkish Lira' => 'TRL - Turkse lire',
    'The project email is optional and could be used by several plugins.' => 'Het e-mailadres van het project is optioneel en kan door verschillende plugins worden gebruikt.',
    'The project email must be unique across all projects' => 'Het project e-mailadres moet uniek zijn voor alle projecten',
    'The email configuration has been disabled by the administrator.' => 'De e-mailconfiguratie is uitgeschakeld door de beheerder.',
    'Close this project' => 'Dit project sluiten',
    'Open this project' => 'Dit project openen',
    'Close a project' => 'Sluit een project',
    'Do you really want to close this project: "%s"?' => 'Wil je dit project echt sluiten: "%s"?',
    'Reopen a project' => 'Heropen dit project',
    'Do you really want to reopen this project: "%s"?' => 'Wil je dit project echt heropenen: "%s"?',
    'This project is open' => 'Dit project is open',
    'This project is closed' => 'Dit project is gesloten',
    'Unable to upload files, check the permissions of your data folder.' => 'Kan geen bestanden uploaden, controleer de rechten van je gegevensmap.',
    'Another category with the same name exists in this project' => 'Er bestaat een andere categorie met dezelfde naam in dit project',
    'Comment sent by email successfully.' => 'Commentaar succesvol verzonden per e-mail.',
    'Sent by email to "%s" (%s)' => 'Per e-mail verzonden naar "%s" (%s)',
    'Unable to read uploaded file.' => 'Kan geüpload bestand niet lezen.',
    'Database uploaded successfully.' => 'Database succesvol geüpload.',
    'Task sent by email successfully.' => 'Taak succesvol verzonden per e-mail.',
    'There is no category in this project.' => 'Er is geen categorie in dit project.',
    'Send by email' => 'Per e-mail verzenden',
    'Create and send a comment by email' => 'Een opmerking maken en verzenden per e-mail',
    'Subject' => 'Onderwerp',
    'Upload the database' => 'De database uploaden',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Je kunt de eerder gedownloade Sqlite-database uploaden (Gzip-formaat).',
    'Database file' => 'Bestand database',
    'Upload' => 'uploaden',
    'Your project must have at least one active swimlane.' => 'Je project moet ten minste één actieve swimlane hebben.',
    'Project: %s' => 'Project: %s',
    'Automatic action not found: "%s"' => 'Automatische actie niet gevonden: "%s"',
    '%d projects' => '%d projecten',
    '%d project' => '%d project',
    'There is no project.' => 'Er is geen project.',
    'Sort' => 'Sorteren',
    'Project ID' => 'Project-ID',
    'Project name' => 'Naam project',
    'Public' => 'Publiek',
    'Personal' => 'Persoonlijk',
    '%d tasks' => '%d taken',
    '%d task' => '%d taak',
    'Task ID' => 'Taak-ID',
    'Assign automatically a color when due date is expired' => 'Wijs automatisch een kleur toe als de deadline is verstreken',
    'Total score in this column across all swimlanes' => 'Totale score in deze kolom over alle swimlanes',
    'HRK - Kuna' => 'HRK - kuna',
    'ARS - Argentine Peso' => 'ARS - Argentijnse peso',
    'COP - Colombian Peso' => 'COP - Colombiaanse peso',
    '%d groups' => '%d groepen',
    '%d group' => '%d groep',
    'Group ID' => 'Groep ID',
    'External ID' => 'Externe ID',
    '%d users' => '%d gebruikers',
    '%d user' => '%d gebruiker',
    'Hide subtasks' => 'Subtaken verbergen',
    'Show subtasks' => 'Subtaken weergeven',
    'Authentication Parameters' => 'Verificatieparameters',
    'API Access' => 'API toegang',
    'No users found.' => 'Geen gebruikers gevonden',
    'User ID' => 'Gebruikers-ID',
    'Notifications are activated' => 'Meldingen zijn geactiveerd',
    'Notifications are disabled' => 'Meldingen zijn uitgeschakeld',
    'User disabled' => 'Gebruiker uitgeschakeld',
    '%d notifications' => '%d meldingen',
    '%d notification' => '%d melding',
    'There is no external integration installed.' => 'Er is geen externe integratie geïnstalleerd.',
    'You are not allowed to update tasks assigned to someone else.' => 'Je mag taken die aan iemand anders zijn toegewezen niet bijwerken.',
    'You are not allowed to change the assignee.' => 'Je mag de toegewezene niet wijzigen.',
    'Task suppression is not permitted' => 'Taakonderdrukking is niet toegestaan',
    'Changing assignee is not permitted' => 'Het wijzigen van de toegewezene is niet toegestaan',
    'Update only assigned tasks is permitted' => 'Alleen toegewezen taken bijwerken is toegestaan',
    'Only for tasks assigned to the current user' => 'Alleen voor taken die zijn toegewezen aan de huidige gebruiker',
    'My projects' => 'Mijn projecten',
    'You are not a member of any project.' => 'Je bent geen lid van een project.',
    'My subtasks' => 'Mijn subtaken',
    '%d subtasks' => '%d subtaken',
    '%d subtask' => '%d subtaken',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Alleen het verplaatsen van taken tussen deze kolommen is toegestaan voor taken die zijn toegewezen aan de huidige gebruiker.',
    '[DUPLICATE]' => '[DUPLICEREN]',
    'DKK - Danish Krona' => 'DKK - Deense kroon',
    'Remove user from group' => 'Verwijder gebruiker uit groep',
    'Assign the task to its creator' => 'Wijs de taak toe aan de maker',
    'This task was sent by email to "%s" with subject "%s".' => 'Deze taak is per e-mail verzonden naar "%s" met als onderwerp "%s".',
    'Predefined Email Subjects' => 'Vooraf gedefinieerde e-mailonderwerpen',
    'Write one subject by line.' => 'Schrijf een onderwerp per regel.',
    'Create another link' => 'Maak een andere link',
    'BRL - Brazilian Real' => 'BRL - Braziliaanse real',
    'Add a new Kanboard task' => 'Een nieuwe Kanboard-taak toevoegen',
    'Subtask not started' => 'Subtaak niet gestart',
    'Subtask currently in progress' => 'Subtaak momenteel bezig',
    'Subtask completed' => 'Subtaak voltooid',
    'Subtask added successfully.' => 'Subtaak succesvol toegevoegd.',
    '%d subtasks added successfully.' => '%d subtaken succesvol toegevoegd.',
    'Enter one subtask by line.' => 'Voer één subtaak per regel in.',
    'Predefined Contents' => 'Vooraf gedefinieerde inhoud',
    'Predefined contents' => 'Vooraf gedefinieerde inhoud',
    'Predefined Task Description' => 'Vooraf gedefinieerde taakbeschrijving',
    'Do you really want to remove this template? "%s"' => 'Wil je deze sjabloon echt verwijderen? "%s"',
    'Add predefined task description' => 'Vooraf gedefinieerde taakbeschrijving toevoegen',
    'Predefined Task Descriptions' => 'Vooraf gedefinieerde taakbeschrijvingen',
    'Template created successfully.' => 'Sjabloon succesvol aangemaakt.',
    'Unable to create this template.' => 'Kan deze sjabloon niet aanmaken.',
    'Template updated successfully.' => 'Sjabloon bijgewerkt.',
    'Unable to update this template.' => 'Kan deze sjabloon niet bijwerken.',
    'Template removed successfully.' => 'Sjabloon met succes verwijderd.',
    'Unable to remove this template.' => 'Kan deze sjabloon niet verwijderen.',
    'Template for the task description' => 'Sjabloon voor de taakbeschrijving',
    'The start date is greater than the end date' => 'De begindatum is groter dan de einddatum',
    'Tags must be separated by a comma' => 'Tags moeten worden gescheiden door een komma',
    'Only the task title is required' => 'Alleen de taaktitel is verplicht',
    'Creator Username' => 'Bedenker Gebruikersnaam',
    'Color Name' => 'Kleur Naam',
    'Column Name' => 'Kolom Naam',
    'Swimlane Name' => 'Naam swimlane',
    'Time Estimated' => 'Geschatte tijd',
    'Time Spent' => 'Bestede tijd',
    'External Link' => 'Externe link',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Deze functie schakelt de iCal feed, RSS feed en de openbare bordweergave in.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Stop de timer van alle subtaken wanneer je een taak naar een andere kolom verplaatst',
    'Subtask Title' => 'Subtaak Titel',
    'Add a subtask and activate the timer when moving a task to another column' => 'Voeg een subtaak toe en activeer de timer bij het verplaatsen van een taak naar een andere kolom',
    'days' => 'dagen',
    'minutes' => 'minuten',
    'seconds' => 'seconden',
    'Assign automatically a color when preset start date is reached' => 'Automatisch een kleur toewijzen wanneer een vooraf ingestelde begindatum is bereikt',
    'Move the task to another column once a predefined start date is reached' => 'Verplaats de taak naar een andere kolom wanneer een vooraf ingestelde begindatum is bereikt',
    'This task is now linked to the task %s with the relation "%s"' => 'Deze taak is nu gekoppeld aan de taak %s met de relatie "%s".',
    'The link with the relation "%s" to the task %s has been removed' => 'De link met de relatie "%s" naar de taak %s is verwijderd',
    'Custom Filter:' => 'Aangepast filter:',
    'Unable to find this group.' => 'Deze groep kan niet worden gevonden',
    '%s moved the task #%d to the column "%s"' => '%s heeft de taak #%d naar de kolom "%s" verplaatst',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s verplaatste de taak #%d naar de positie %d in de kolom "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s heeft de taak #%d verplaatst naar de swimlane "%s".',
    '%sh spent' => '%sh besteed',
    '%sh estimated' => '%sh geschat',
    'Select All' => 'Alles selecteren',
    'Unselect All' => 'Alles deselecteren',
    'Apply action' => 'Actie toepassen',
    'Move selected tasks to another column or swimlane' => 'Verplaats geselecteerde taken naar een andere kolom of swimlane',
    'Edit tasks in bulk' => 'Taken in bulk bewerken',
    'Choose the properties that you would like to change for the selected tasks.' => 'Kies de eigenschappen die je wilt wijzigen voor de geselecteerde taken.',
    'Configure this project' => 'Configureer dit project',
    'Start now' => 'Start nu',
    '%s removed a file from the task #%d' => '%s heeft een bestand verwijderd uit de taak #%d',
    'Attachment removed from task #%d: %s' => 'Bijlage verwijderd uit taak #%d: %s',
    'No color' => 'Geen kleur',
    'Attachment removed "%s"' => 'Bijlage verwijderd "%s".',
    '%s removed a file from the task %s' => '%s heeft een bestand van de taak %s verwijderd',
    'Move the task to another swimlane when assigned to a user' => 'Verplaats de taak naar een andere swimlane wanneer deze is toegewezen aan een gebruiker',
    'Destination swimlane' => 'Bestemming swimlane',
    'Assign a category when the task is moved to a specific swimlane' => 'Een categorie toewijzen wanneer de taak wordt verplaatst naar een specifieke swimlane',
    'Move the task to another swimlane when the category is changed' => 'Verplaats de taak naar een ander swimlane wanneer de categorie is gewijzigd',
    'Reorder this column by priority (ASC)' => 'Herschik deze kolom op prioriteit (oplopend)',
    'Reorder this column by priority (DESC)' => 'Herschik deze kolom op prioriteit (aflopend)',
    'Reorder this column by assignee and priority (ASC)' => 'Herschik deze kolom op ontvanger en prioriteit (oplopend)',
    'Reorder this column by assignee and priority (DESC)' => 'Sorteer deze kolom opnieuw op geadresseerde en prioriteit (aflopend)',
    'Reorder this column by assignee (A-Z)' => 'Sorteer deze kolom opnieuw op geadresseerde (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Sorteer deze kolom opnieuw op geadresseerde (Z-A)',
    'Reorder this column by due date (ASC)' => 'Sorteer deze kolom opnieuw op vervaldatum (oplopend)',
    'Reorder this column by due date (DESC)' => 'Sorteer deze kolom opnieuw op vervaldatum (aflopend)',
    'Reorder this column by id (ASC)' => 'Sorteer deze kolom opnieuw op id (oplopend)',
    'Reorder this column by id (DESC)' => 'Sorteer deze kolom opnieuw op id (aflopend)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s heeft de taak #%d "%s" verplaatst naar het project "%s".',
    'Task #%d "%s" has been moved to the project "%s"' => 'Taak #%d "%s" is verplaatst naar het project "%s".',
    'Move the task to another column when the due date is less than a certain number of days' => 'Verplaats de taak naar een andere kolom wanneer de vervaldatum minder is dan een bepaald aantal dagen',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automatisch de begindatum bijwerken wanneer de taak wordt verplaatst uit een specifieke kolom',
    'HTTP Client:' => 'HTTP-client',
    'Assigned' => 'Toegekend',
    'Task limits apply to each swimlane individually' => 'Taaklimieten gelden voor elke swimlane afzonderlijk',
    'Column task limits apply to each swimlane individually' => 'Kolom taaklimieten zijn van toepassing op elke swimlane afzonderlijk',
    'Column task limits are applied to each swimlane individually' => 'Kolomtaaklimieten worden toegepast op elke swimlane afzonderlijk',
    'Column task limits are applied across swimlanes' => 'Kolom taaklimieten worden toegepast op alle swimlanes',
    'Task limit: ' => 'Taaklimiet',
    'Change to global tag' => 'Globale tag wijzigen',
    'Do you really want to make the tag "%s" global?' => 'Wil je de tag "%s" echt globaal maken?',
    'Enable global tags for this project' => 'Globale tags inschakelen voor dit project',
    'Group membership(s):' => 'Groep lidmaatschap(pen)',
    '%s is a member of the following group(s): %s' => '%s is lid van de volgende groep(en): %s',
    '%d/%d group(s) shown' => '%d/%d groep(en) getoond',
    'Subtask creation or modification' => 'Subtaak aanmaken of wijzigen',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Wijs de taak toe aan een specifieke gebruiker wanneer de taak wordt verplaatst naar een specifieke swimlane',
    'Comment' => 'Commentaar',
    'Collapse vertically' => 'Verticaal samenvouwen',
    'Expand vertically' => 'Verticaal uitvouwen',
    'MXN - Mexican Peso' => 'MXN - Mexicaanse peso',
    'Estimated vs actual time per column' => 'Geschatte vs werkelijke tijd per kolom',
    'HUF - Hungarian Forint' => 'HUF - Hongaarse forint',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'U moet een bestand selecteren om als uw avatar te uploaden!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Het bestand dat u heeft geüpload is geen geldige afbeelding! (Alleen *.gif, *.jpg, *.jpeg en *.png zijn toegestaan!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Stel automatisch de vervaldatum in wanneer de taak uit een specifieke kolom wordt verplaatst',
    'No other projects found.' => 'Geen andere projecten gevonden.',
    'Tasks copied successfully.' => 'Taken succesvol gekopieerd.',
    'Unable to copy tasks.' => 'Kan taken niet kopiëren.',
    'Theme' => 'Thema',
    'Theme:' => 'Thema:',
    'Light theme' => 'Licht thema',
    'Dark theme' => 'Donker thema',
    'Automatic theme - Sync with system' => 'Automatisch thema - Synchroniseren met systeem',
    'Application managers or more' => 'Applicatiebeheerders of meer',
    'Administrators' => 'Beheerders',
    'Visibility:' => 'Zichtbaarheid:',
    'Standard users' => 'Standaardgebruikers',
    'Visibility is required' => 'Zichtbaarheid is vereist',
    'The visibility should be an app role' => 'De zichtbaarheid moet een app-rol zijn',
    'Reply' => 'Beantwoorden',
    '%s wrote: ' => '%s schreef: ',
    'Number of visible tasks in this column and swimlane' => 'Aantal zichtbare taken in deze kolom en swimlane',
    'Number of tasks in this swimlane' => 'Aantal taken in deze swimlane',
    'Unable to find another subtask in progress, you can close this window.' => 'Kan geen andere subtaak in uitvoering vinden, u kunt dit venster sluiten.',
    'This theme is invalid' => 'Dit thema is ongeldig',
    'This role is invalid' => 'Deze rol is ongeldig',
    'This timezone is invalid' => 'Deze tijdzone is ongeldig',
    'This language is invalid' => 'Deze taal is ongeldig',
    'This URL is invalid' => 'Deze URL is ongeldig',
    'Date format invalid' => 'Ongeldig datumnotatie',
    'Time format invalid' => 'Ongeldige tijdnotatie',
    'Invalid Mail transport' => 'Ongeldige mailtransport',
    'Color invalid' => 'Ongeldige kleur',
    'This value must be greater or equal to %d' => 'Deze waarde moet groter of gelijk zijn aan %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Voeg een BOM toe aan het begin van het bestand (vereist voor Microsoft Excel)',
    'Just add these tag(s)' => 'Voeg alleen deze tags toe',
    'Remove internal link(s)' => 'Verwijder interne links',
    'Import tasks from another project' => 'Importeer taken uit een ander project',
    'Select the project to copy tasks from' => 'Selecteer het project waarvan u taken wilt kopiëren',
    'The total maximum allowed attachments size is %sB.' => 'De maximaal toegestane totale grootte voor bijlagen is %sB.',
    'Add attachments' => 'Bijlagen toevoegen',
    'Task #%d "%s" is overdue' => 'Taak #%d "%s" is te laat',
    'Enable notifications by default for all new users' => 'Standaard meldingen inschakelen voor alle nieuwe gebruikers',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Wijs de taak toe aan de maker voor specifieke kolommen als er niet handmatig een gebruiker is toegewezen',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Wijs een taak toe aan de ingelogde gebruiker bij het wijzigen van kolom naar de opgegeven kolom als er geen gebruiker is toegewezen',
];
